@@ -13,23 +13,24 @@ our @ISA = qw(Exporter);
 our @EXPORT_OK = qw( kto_check kto_check_str kto_check_blz
    kto_check_pz generate_lut generate_lut2 lut_cleanup lut_valid
    lut_init kto_check_init copy_lutfile lut_multiple lut_filialen
-   lut_blz lut_name lut_name_kurz lut_plz lut_ort lut_pan lut_bic lut_pz
-   lut_aenderung lut_loeschung lut_nachfolge_blz
-   lut_blz1 lut_name1 lut_name_kurz1 lut_plz1 lut_ort1 lut_pan1 lut_bic1 lut_pz1
-   lut_aenderung1 lut_loeschung1 lut_nachfolge_blz1
-   lut_info iban2bic pz2str
+   lut_name lut_name_kurz lut_plz lut_ort lut_pan lut_bic lut_pz
+   lut_aenderung lut_loeschung lut_nachfolge_blz lut_info iban2bic
    iban_gen check_iban ipi_check ipi_gen set_verbose_debug
-   retval2txt retval2txt_short retval2utf8 retval2html retval2dos
    kto_check_retval2txt kto_check_retval2txt_short kto_check_retval2utf8
    kto_check_retval2html dump_lutfile kto_check_retval2dos
    lut_suche_blz lut_suche_pz lut_suche_plz lut_suche_bic
    lut_suche_namen lut_suche_namen_kurz lut_suche_ort
-   konto_check_at kto_check_at_str generate_lut_at
-   %kto_retval %kto_retval_kurz );
+   lut_suche_blz_idx lut_suche_pz_idx lut_suche_plz_idx
+   lut_suche_bic_idx lut_suche_namen_idx lut_suche_namen_kurz_idx
+   lut_suche_ort_idx lut_suche_blz_blz lut_suche_pz_blz
+   lut_suche_plz_blz lut_suche_bic_blz lut_suche_namen_blz
+   lut_suche_namen_kurz_blz lut_suche_ort_blz
+   konto_check_at kto_check_at_str generate_lut_at %kto_retval
+   %kto_retval_kurz  lut_suche_namen_idx lut_suche_namen_blz );
 
-our @EXPORT = qw( lut_init kto_check kto_check_blz kto_check_at %kto_retval );
+our @EXPORT = qw( kto_check lut_init kto_check_blz kto_check_at %kto_retval );
 
-our $VERSION = '3.2.1';
+our $VERSION = '3.1';
 
 require XSLoader;
 XSLoader::load('Business::KontoCheck', $VERSION);
@@ -44,7 +45,6 @@ sub lut_info
    my $info2;
    my $valid1;
    my $valid2;
-   my $lut_dir;
    my $args;
 
    if(scalar(@_)==1){
@@ -56,11 +56,11 @@ sub lut_info
       $args=-2;
    }
    if(wantarray()){
-      $ret=lut_info_i($lut_name,1+$args,$info1,$valid1,$info2,$valid2,$lut_dir);
-      return ($ret,$info1,$valid1,$info2,$valid2,$lut_dir);
+      $ret=lut_info_i($lut_name,1+$args,$info1,$valid1,$info2,$valid2);
+      return ($ret,$info1,$valid1,$info2,$valid2);
    }
    else{
-      $ret=lut_info_i($lut_name,$args,$info1,$valid1,$info2,$valid2,$lut_dir);
+      $ret=lut_info_i($lut_name,$args,$info1,$valid1,$info2,$valid2);
       return $ret;
    }
 }
@@ -150,6 +150,25 @@ sub lut_suche_bic
    }
 }
 
+sub lut_suche_bic_blz
+{
+   if(wantarray()){
+      return lut_suche_c(3,1,@_);
+   }
+   else{
+      return lut_suche_c(2,1,@_);
+   }
+}
+
+sub lut_suche_bic_idx
+{
+   if(wantarray()){
+      return lut_suche_c(5,1,@_);
+   }
+   else{
+      return lut_suche_c(4,1,@_);
+   }
+}
 
 sub lut_suche_namen
 {
@@ -161,6 +180,25 @@ sub lut_suche_namen
    }
 }
 
+sub lut_suche_namen_blz
+{
+   if(wantarray()){
+      return lut_suche_c(3,2,@_);
+   }
+   else{
+      return lut_suche_c(2,2,@_);
+   }
+}
+
+sub lut_suche_namen_idx
+{
+   if(wantarray()){
+      return lut_suche_c(5,2,@_);
+   }
+   else{
+      return lut_suche_c(4,2,@_);
+   }
+}
 
 sub lut_suche_namen_kurz
 {
@@ -172,6 +210,25 @@ sub lut_suche_namen_kurz
    }
 }
 
+sub lut_suche_namen_kurz_blz
+{
+   if(wantarray()){
+      return lut_suche_c(3,3,@_);
+   }
+   else{
+      return lut_suche_c(2,3,@_);
+   }
+}
+
+sub lut_suche_namen_kurz_idx
+{
+   if(wantarray()){
+      return lut_suche_c(5,3,@_);
+   }
+   else{
+      return lut_suche_c(4,3,@_);
+   }
+}
 
 sub lut_suche_ort
 {
@@ -183,6 +240,25 @@ sub lut_suche_ort
    }
 }
 
+sub lut_suche_ort_blz
+{
+   if(wantarray()){
+      return lut_suche_c(3,4,@_);
+   }
+   else{
+      return lut_suche_c(2,4,@_);
+   }
+}
+
+sub lut_suche_ort_idx
+{
+   if(wantarray()){
+      return lut_suche_c(5,4,@_);
+   }
+   else{
+      return lut_suche_c(4,4,@_);
+   }
+}
 
 sub lut_suche_blz
 {
@@ -194,6 +270,25 @@ sub lut_suche_blz
    }
 }
 
+sub lut_suche_blz_blz
+{
+   if(wantarray()){
+      return lut_suche_i(3,1,@_);
+   }
+   else{
+      return lut_suche_i(2,1,@_);
+   }
+}
+
+sub lut_suche_blz_idx
+{
+   if(wantarray()){
+      return lut_suche_i(5,1,@_);
+   }
+   else{
+      return lut_suche_i(4,1,@_);
+   }
+}
 
 sub lut_suche_pz
 {
@@ -205,6 +300,25 @@ sub lut_suche_pz
    }
 }
 
+sub lut_suche_pz_blz
+{
+   if(wantarray()){
+      return lut_suche_i(3,2,@_);
+   }
+   else{
+      return lut_suche_i(2,2,@_);
+   }
+}
+
+sub lut_suche_pz_idx
+{
+   if(wantarray()){
+      return lut_suche_i(5,2,@_);
+   }
+   else{
+      return lut_suche_i(4,2,@_);
+   }
+}
 
 sub lut_suche_plz
 {
@@ -216,26 +330,27 @@ sub lut_suche_plz
    }
 }
 
-
-
-sub lut_blz
+sub lut_suche_plz_blz
 {
-   my $r;
-
-   $r=lut_blz_i(@_);
    if(wantarray()){
-      return ($r,$Business::KontoCheck::kto_retval{$r},$Business::KontoCheck::kto_retval_kurz{$r});
+      return lut_suche_i(3,3,@_);
    }
    else{
-      return $r;
+      return lut_suche_i(2,3,@_);
    }
 }
 
-sub lut_blz1
+sub lut_suche_plz_idx
 {
-   return lut_blz_i(@_);
+   if(wantarray()){
+      return lut_suche_i(5,3,@_);
+   }
+   else{
+      return lut_suche_i(4,3,@_);
+   }
 }
 
+
 sub lut_name
 {
    my $r=1;
@@ -250,13 +365,6 @@ sub lut_name
    }
 }
 
-sub lut_name1
-{
-   my $r=1;
-
-   return lut_name_i($r,@_);
-}
-
 sub lut_name_kurz
 {
    my $r=1;
@@ -271,13 +379,6 @@ sub lut_name_kurz
    }
 }
 
-sub lut_name_kurz1
-{
-   my $r=1;
-
-   return lut_name_kurz_i($r,@_);
-}
-
 sub lut_plz
 {
    my $r=1;
@@ -292,13 +393,6 @@ sub lut_plz
    }
 }
 
-sub lut_plz1
-{
-   my $r=1;
-
-   return lut_plz_i($r,@_);
-}
-
 sub lut_ort
 {
    my $r=1;
@@ -313,13 +407,6 @@ sub lut_ort
    }
 }
 
-sub lut_ort1
-{
-   my $r=1;
-
-   return lut_ort_i($r,@_);
-}
-
 sub lut_pan
 {
    my $r=1;
@@ -334,13 +421,6 @@ sub lut_pan
    }
 }
 
-sub lut_pan1
-{
-   my $r=1;
-
-   return lut_pan_i($r,@_);
-}
-
 sub lut_bic
 {
    my $r=1;
@@ -355,13 +435,6 @@ sub lut_bic
    }
 }
 
-sub lut_bic1
-{
-   my $r=1;
-
-   return lut_bic_i($r,@_);
-}
-
 sub lut_pz
 {
    my $r=1;
@@ -376,13 +449,6 @@ sub lut_pz
    }
 }
 
-sub lut_pz1
-{
-   my $r=1;
-
-   return lut_pz_i($r,@_);
-}
-
 sub lut_aenderung
 {
    my $r=1;
@@ -397,13 +463,6 @@ sub lut_aenderung
    }
 }
 
-sub lut_aenderung1
-{
-   my $r=1;
-
-   return lut_aenderung_i($r,@_);
-}
-
 sub lut_loeschung
 {
    my $r=1;
@@ -418,13 +477,6 @@ sub lut_loeschung
    }
 }
 
-sub lut_loeschung1
-{
-   my $r=1;
-
-   return lut_loeschung_i($r,@_);
-}
-
 sub lut_nachfolge_blz
 {
    my $r=1;
@@ -439,13 +491,6 @@ sub lut_nachfolge_blz
    }
 }
 
-sub lut_nachfolge_blz1
-{
-   my $r=1;
-
-   return lut_nachfolge_blz_i($r,@_);
-}
-
 
 %Business::KontoCheck::kto_retval = (
 -110 => 'wahrscheinlich OK; es wurde allerdings ein (weggelassenes) Unterkonto angefgt',
@@ -842,7 +887,7 @@ language is german too.
    use Business::KontoCheck;
    use Business::KontoCheck qw( kto_check lut_name lut_blz lut_ort %kto_retval [...] );
 
-   $retval=lut_init([$lut_name[,$required[,$set]]]);
+   $retval=lut_init([$lut_name[,$required[,$set]]);
    $retval=kto_check_init($lut_name[,$required[,$set[,$incremental]]]);
    $retval=kto_check($blz,$kto,$lut_name);
    $retval=kto_check_str($blz,$kto,$lut_name);
@@ -852,7 +897,7 @@ language is german too.
    $retval=generate_lut($inputname,$outputname,$user_info,$lut_version);
    $retval=generate_lut2($inputname,$outputname[,$user_info[,$gueltigkeit[,$felder[,$filialen[,$slots[,$lut_version[,$set]]]]]]]);
 
-   [$@]retval=lut_blz($blz[,$offset])
+   $retval=lut_valid()
    [$@]retval=lut_info($lut_name)
    [$@]retval=lut_filialen($blz[,$offset])
    [$@]retval=lut_name($blz[,$offset])
@@ -866,16 +911,13 @@ language is german too.
    [$@]retval=lut_loeschung($blz[,$offset])
    [$@]retval=lut_nachfolge_blz($blz[,$offset])
 
-   $retval=lut_valid()
-   $ret=pz2str($pz[,$ret])
-
-   [$@]bic=lut_suche_bic($bic[,$retval])
-   [$@]namen=lut_suche_namen($namen[,$retval])
-   [$@]namen_kurz=lut_suche_namen_kurz($namen_kurz])
-   [$@]ort=lut_suche_ort($ort[,$retval])
-   [$@]blz=lut_suche_blz($blz1[,$blz2[,$retval]])
-   [$@]pz=lut_suche_pz($pz1[,$pz2[,$retval]])
-   [$@]plz=lut_suche_plz($plz1[,$plz2[,$retval]])
+   [$@]bic=lut_suche_bic($bic[,$retval[,$zweigstelle[,$blz]]])
+   [$@]namen=lut_suche_namen($namen[,$retval[,$zweigstelle[,$blz]]])
+   [$@]namen_kurz=lut_suche_namen_kurz($namen_kurz[,$retval[,$zweigstelle[,$blz]]])
+   [$@]ort=lut_suche_ort($ort[,$retval[,$zweigstelle[,$blz]]])
+   [$@]blz=lut_suche_blz($blz1[,$blz2[,$retval[,$zweigstelle[,$blz]]]])
+   [$@]pz=lut_suche_pz($pz1[,$pz2[,$retval[,$zweigstelle[,$blz]]]])
+   [$@]plz=lut_suche_plz($plz1[,$plz2[,$retval[,$zweigstelle[,$blz]]]])
 
    $retval=copy_lutfile($old_name,$new_name,$new_slots)
    $retval=dump_lutfile($outputname,$felder)
@@ -890,11 +932,6 @@ language is german too.
    $retval=retval2html($retval)
    $retval=retval2utf8($retval)
    $retval=retval2dos($retval)
-   $retval=kto_check_retval2txt($retval)
-   $retval=kto_check_retval2txt_short($retval)
-   $retval=kto_check_retval2html($retval)
-   $retval=kto_check_retval2utf8($retval)
-   $retval=kto_check_retval2dos($retval)
    $retval_txt=$kto_retval{$retval};
 
    $retval=kto_check_at($blz,$kto,$lut_name);
@@ -903,9 +940,13 @@ language is german too.
 
 =head1 DESCRIPTION
 
-Dies ist Business::KontoCheck, ein Programm zum Testen der Prfziffern
-von deutschen und sterreichischen Bankkonten. Dies ist die
-Perl-Version der C-Library (als XSUB Modul).
+Dies ist Business::KontoCheck, ein Programm zum Testen der
+Prfziffern von deutschen und sterreichischen Bankkonten. Es war
+ursprnglich fr die Benutzung mit dem dtaus-Paket von Martin
+Schulze <joey@infodrom.org> und dem lx2l Prprozessor gedacht;
+es lt sich jedoch auch mit beliebigen anderen Programmen
+verwenden. Dies ist die Perl-Version der C-Library (als XSUB
+Modul).
 
 =head1 EXPORT
 
@@ -945,19 +986,19 @@ diese mssen dann in der use Klausel anzugeben werden.
                 werden.
 
   Rckgabewerte:
-     Die Funktion kto_check gibt einen numerischen Wert zurck,
-     whrend die Funktion kto_check_str einen kurzen String
-     zurckgibt.
+     Die Funktion kto_check gibt einen numerischen Wert zurck, whrend die
+     Funktion kto_check_str einen kurzen String zurckgibt.
+     Werte sind definiert3
 
-     Mittels des assoziativen Arrays %kto_retval lassen sich die
-     numerischen Rckgabewerte in einen etwas ausfhrlicheren
-     Rckgabetext umwandeln:
+     Mittels des assoziativen Arrays %kto_retval lassen sich die numerischen
+     und kurzen Rckgabewerte in einen etwas ausfhrlicheren Rckgabetext
+     umwandeln:
 
      $retval_txt=$kto_retval{$retval};
 
 -------------------------------------------------------------------------
 
-  Funktion:  generate_lut()      (LUT-Version 1.0 oder 1.1; obsolet)
+  Funktion:  generate_lut()      (LUT-Version 1.0 oder 1.1)
              generate_lut2()     (LUT-Version 1.0, 1.1 oder 2.0)
 
   Aufgabe:   LUT-Datei generieren
@@ -1009,8 +1050,7 @@ diese mssen dann in der use Klausel anzugeben werden.
 
 -------------------------------------------------------------------------
 
-  Funktion:  lut_blz()
-             lut_filialen()
+  Funktion:  lut_filialen()
              lut_name()
              lut_name_kurz()
              lut_plz()
@@ -1024,18 +1064,16 @@ diese mssen dann in der use Klausel anzugeben werden.
 
   Aufgabe:   Bestimmung von Feldern der BLZ-Datei
 
-  Aufruf:    [$@]ret=lut_blz($blz[,$filiale[,$ret]])
-             [$@]ret=lut_name($blz[,$filiale[,$ret]])
-             [$@]ret=lut_name_kurz($blz[,$filiale[,$ret]])
-             [$@]ret=lut_plz($blz[,$filiale[,$ret]])
-             [$@]ret=lut_ort($blz[,$filiale[,$ret]])
-             [$@]ret=lut_pan($blz[,$filiale[,$ret]])
-             [$@]ret=lut_bic($blz[,$filiale[,$ret]])
-             [$@]ret=lut_pz($blz[,$filiale[,$ret]])
-             [$@]ret=lut_aenderung($blz[,$filiale[,$ret]])
-             [$@]ret=lut_loeschung($blz[,$filiale[,$ret]])
-             [$@]ret=lut_nachfolge_blz($blz[,$filiale[,$ret]])
-             $ret=pz2str($pz[,$ret])
+  Aufruf:    [$@]ret=lut_name($blz[,$filiale])
+             [$@]ret=lut_name_kurz($blz[,$filiale])
+             [$@]ret=lut_plz($blz[,$filiale])
+             [$@]ret=lut_ort($blz[,$filiale])
+             [$@]ret=lut_pan($blz[,$filiale])
+             [$@]ret=lut_bic($blz[,$filiale])
+             [$@]ret=lut_pz($blz[,$filiale])
+             [$@]ret=lut_aenderung($blz[,$filiale])
+             [$@]ret=lut_loeschung($blz[,$filiale])
+             [$@]ret=lut_nachfolge_blz($blz[,$filiale])
 
    Die Funktionen bestimmen die diversen Felder der BLZ-Datei zu einer
    gegebenen BLZ. Falls der optionale Parameter $filiale angegeben
@@ -1044,15 +1082,11 @@ diese mssen dann in der use Klausel anzugeben werden.
    einer BLZ lt sich mittels der Funktion $cnt=lut_filialen($blz)
    bestimmen.
 
-   Die Funktion pz2str() wandelt eine numerische Prfziffermethode
-   (wie sie z.B. von lut_pz() zurckgegeben wird) in einen
-   zweistelligen String um.
-
-   Alle Funktionen (auer pz2str) lassen sich sowohl im skalaren als
-   auch im Array-Kontext aufrufen. Bei Aufruf in skalarem Kontext wird
-   der jeweilige Wert zurckgegeben; bei Aufruf im Array-Kontext wird
-   auerdem noch der Rckgabestatus der Funktion als Zahl, String
-   (lang) und String (kurz) zurckgegeben. Beispiel:
+   Alle Funktionen lassen sich sowohl im skalaren als auch im Array-
+   Kontext aufrufen. Bei Aufruf in skalarem Kontext wird der jeweilige
+   Wert zurckgegeben; bei Aufruf im Array-Kontext wird auerdem noch
+   der Rckgabestatus der Funktion als Zahl, String (lang) und String
+   (kurz) zurckgegeben. Beispiel:
 
    $ret=lut_name("66090800") liefert fr $ret den Wert "BBBank",
    @ret=lut_name("66090800") liefert ein Array mit den Werten
@@ -1062,106 +1096,56 @@ diese mssen dann in der use Klausel anzugeben werden.
    @ret=lut_name("660908") liefert ein Array mit den Werten
    @ret=("",-5,"die Bankleitzahl ist nicht achtstellig","INVALID_BLZ_LENGTH")
 
-   Falls der Aufruf im Array-Kontext nicht gewnscht ist, gibt es noch
-   alternative Funktionen, die nur in skalarem Kontext arbeiten: 
-
-   -------------------------------------------------------------------------
-
-  Funktion:  lut_blz1()
-             lut_filialen1()
-             lut_name1()
-             lut_name_kurz1()
-             lut_plz1()
-             lut_ort1()
-             lut_pan1()
-             lut_bic1()
-             lut_pz1()
-             lut_aenderung1()
-             lut_loeschung1()
-             lut_nachfolge_blz1()
-
-  Aufgabe:   Bestimmung von Feldern der BLZ-Datei (skalarer Kontext)
-
-  Aufruf:    $ret=lut_blz1($blz[,$filiale[,$ret]])
-             $ret=lut_name1($blz[,$filiale[,$ret]])
-             $ret=lut_name_kurz1($blz[,$filiale[,$ret]])
-             $ret=lut_plz1($blz[,$filiale[,$ret]])
-             $ret=lut_ort1($blz[,$filiale[,$ret]])
-             $ret=lut_pan1($blz[,$filiale[,$ret]])
-             $ret=lut_bic1($blz[,$filiale[,$ret]])
-             $ret=lut_pz1($blz[,$filiale[,$ret]])
-             $ret=lut_aenderung1($blz[,$filiale[,$ret]])
-             $ret=lut_loeschung1($blz[,$filiale[,$ret]])
-             $ret=lut_nachfolge_blz1($blz[,$filiale[,$ret]])
-             $ret=pz2str1($pz[,$ret])
-
-   Die Funktionen entsprechen den Funktionen ohne die angehngte "1";
-   allerdings arbeiten sie ausschlielich im skalaren Kontext. Das ist
-   z.B. vorteilhaft, wenn man den Rckgabewert der Funktion in einem
-   anderen Funktionsaufruf benutzen will. Der Rckgabewert der
-   Funktion kann mittels des optionalen Parameters $ret bestimmt
-   werden.
 
 -------------------------------------------------------------------------
 
-  Funktion:  lut_suche_blz()
-             lut_suche_bic()
+  Funktion:  lut_suche_bic()
              lut_suche_namen()
              lut_suche_namen_kurz()
              lut_suche_ort()
+             lut_suche_blz()
              lut_suche_pz()
              lut_suche_plz()
 
   Aufgabe:  Suche von Banken (nach Feldern der BLZ-Datei)
 
-  Aufruf:    [$@]ret=lut_suche_bic($bic[,$retval])
-             [$@]ret=lut_suche_namen($namen[,$retval])
-             [$@]ret=lut_suche_namen_kurz($namen_kurz[,$retval])
-             [$@]ret=lut_suche_ort($ort[,$retval])
+  Aufruf:    [$@]ret=lut_suche_bic($bic[,$retval[,$zweigstelle[,$blz]]])
+             [$@]ret=lut_suche_namen($namen[,$retval[,$zweigstelle[,$blz]]])
+             [$@]ret=lut_suche_namen_kurz($namen_kurz[,$retval[,$zweigstelle[,$blz]]])
+             [$@]ret=lut_suche_ort($ort[,$retval[,$zweigstelle[,$blz]]])
+             [$@]ret=lut_suche_blz($blz1[,$blz2[,$retval[,$zweigstelle[,$blz]]]])
+             [$@]ret=lut_suche_pz($pz1[,$pz2[,$retval[,$zweigstelle[,$blz]]]])
+             [$@]ret=lut_suche_plz($plz1[,$plz2[,$retval[,$zweigstelle[,$blz]]]])
 
-             [$@]ret=lut_suche_blz($blz1[,$blz2[,$retval]])
-             [$@]ret=lut_suche_pz($pz1[,$pz2[,$retval]])
-             [$@]ret=lut_suche_plz($plz1[,$plz2[,$retval]])
-
-   Mit diesen Funktionen lassen sich Banken suchen, die bestimmte
-   Kriterien erfllen. Bei alphanumerischer Suche (BIC, Name,
-   Kurzname, Ort) kann ein vollstndiger Name oder Namensanfang
-   angegeben werden. So findet z.B. eine Suche lut_suche_ort("aa") die
-   Banken in in Aach, Aachen, Aalen und Aarbergen, whrend eine Suche
-   wie lut_suche_ort("aac") nur die Banken in Aach und Aachen findet.
+   Mit diesen Funktionen lassen sich Banken suchen, die bestimmte Kriterien
+   erfllen. Bei alphanumerischer Suche (BIC, Name, Kurzname, Ort) kann ein
+   vollstndiger Name oder Namensanfang angegeben werden. So findet z.B. eine
+   Suche lut_suche_ort("aa") die Banken in in Aach, Aachen, Aalen und Aarbergen,
+   whrend eine Suche wie lut_suche_ort("aac") nur die Banken in Aach und Aachen
+   findet.
 
    Bei numerischer Suche (BLZ, Prfziffer oder PLZ) kann ein Bereich
-   spezifiziert werden. Falls der zweite Suchparameter nicht angegeben
-   wird (oder 0 ist), werden Banken gesucht, die genau auf den
-   Parameter passen.
+   spezifiziert werden. Falls der zweite Suchparameter nicht angegeben wird
+   (oder 0 ist), werden Banken gesucht, die genau auf den Parameter passen.
 
-   Diese Funktionen knnen sowohl in skalarem als auch im
-   Listenkontext aufgerufen werden. Bei Aufruf in skalarem Kontext
-   geben sie eine Referenz auf ein Array mit Bankleitzahlen zurck,
-   die die Kriterien erfllen; bei Aufruf im Listenkontext werden (bis
-   zu) drei Referenzen zurckgegeben. Die erste zeigt auf das Array
-   mit Bankleitzahlen, die zweite auf ein Array mit Indizes der
-   jeweiligen Zweigstellen und die dritte auf ein Array mit den
-   jeweiligen Werten des gesuchten Feldes.
+   Diese Funktionen knnen sowohl in skalarem als auch im Listenkontext
+   aufgerufen werden. Bei Aufruf in skalarem Kontext geben sie die Anzahl Banken
+   zurck, die die spezifizierte Bedingung erfllen; bei Aufruf in Listenkontext
+   wird ein Array zurckgegeben, das die jeweils gesuchten Felder enthlt.
 
-   In dem (optionalen) Parameter $retval wird der numerischer
-   Rckgabewert der Funktion (1 bei Erfolg, oder negative
-   Statusmeldung) zurckgeliefert.. Mittels des assoziativen Arrays
-   %kto_retval{$retval} knnen diese Rckgabewerte in Klartext
-   konvertiert werden.
+   Die Funktionen haben eine Reihe optionaler Parameter:
 
-   Beispiele:
-   $blz_p=lut_suche_ort("mannheim");
-   @blz=@$blz_p;     # Array mit allen Banken in Mannheim
+      $retval:       numerischer Rckgabewert der Funktion (1 bei Erfolg, oder
+                     negative Statusmeldung). Mittels des assoziativen Arrays
+                     %kto_retval{$retval} knnen diese Rckgabewerte in Klartext
+                     konvertiert werden.
 
-   ($blz_p,$idx_p)=lut_suche_ort("mannheim");
-   @blz=@$blz_p;     # Array mit allen Banken in Mannheim
-   @idx=@$idx_p;     # Array der Zweigstellen
+      $zweigstelle:  Referenz auf ein Array, in dem zu jeder Bank der Index der
+                     jeweiligen Zweigstelle enthalten ist; die Hauptstelle wird
+                     mit 0 gekennzeichnet.
 
-   ($blz_p,$idx_p,$ort_p)=lut_suche_ort("aa");
-   @blz=@$blz_p;     # Array mit Banken in Stdten, die mit "aa" beginnen
-   @idx=@$idx_p;     # Array der Zweigstellen
-   @ort=@$ort_p;     # Array der jeweiligen Orte
+      $blz:          Referenz auf ein Array, das die Bankleitzahen der
+                     gefundenen Banken enthlt.
 
 -------------------------------------------------------------------------
 
@@ -1263,23 +1247,35 @@ diese mssen dann in der use Klausel anzugeben werden.
 
 -------------------------------------------------------------------------
 
+
+=head1 BUGS der Version 2.x:
+
+Die alten Problemflle aus Version 2.x sind ab Version 3.0 behoben:
+
+ - Die Funktion generate_lut() benutzt einen eigenen Variablensatz, so
+   da keine Interferenzen mit den Testroutinen auftreten (das git noch
+   nicht fr generate_lut_at()!).
+
+ - Die Bibliothek ist jetzt threadfest
+
+ - Es ist mglich, die Initialisierung mehrfach aufzurufen; der vorher
+    allokierte Speicher wird dabei automatisch freigegeben. Auch eine
+    inkrementelle Initialisierung (bei der nur einige Blocks der
+    LUT-Datei nachgeladen werden) ist mglich. Falls in der LUT-Datei
+    zwei Datenstze enthalten sind (und nicht ein bestimmter
+    ausgewhlt wird), erfolgt die (Neu-)Initialisierung in
+    Abhngigkeit vom aktuellen Datum.
+
+
 =head1 SEE ALSO
 
-Eine ausfhrliche Beschreibung der Prfziffermethoden und das Format
-der LUT-Datei findet sich im C-Quellcode. Ein Link zur offiziellen
-Beschreibung der Prfziffermethoden u.a. (von der Deutschen
-Bundesbank) findet sich auf der Webseite zu konto_check unter
-http://www.informatik.hs-mannheim.de/konto_check/konto_check.php?ausgabe=3
+Eine ausfhrliche Beschreibung der Prfziffermethoden und das Format der
+LUT-Datei findet sich im C-Quellcode.
 
-Auf SourceForge.net gibt es unter http://sourceforge.net/mail/?group_id=199719
-auch eine Mailingliste. Der Traffic ist sehr gering, maximal meist ein bis zwei
-Emails/Monat.
+Eine Mailingliste zu konto_check findet sich auf SourceForge.net unter
+http://sourceforge.net/mail/?group_id=199719
 
-Die aktuelle Version findet sich auf CPAN unter
-http://search.cpan.org/~michel/Business-KontoCheck oder auf
-Sourceforge unter http://sourceforge.net/projects/kontocheck/develop
-Dort ist auch ein SVN Repository, in dem die neuesten Versionen und
-Bugfixes zu finden sind.
+Die aktuelle Version findet sich unter http://www.informatik.hs-mannheim.de/konto_check
 
 =head1 AUTHOR
 
@@ -1287,7 +1283,7 @@ Michael Plugge, E<lt>m.plugge@hs-mannheim.deE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2007-2010 by Michael Plugge
+Copyright (C) 2007-2008 by Michael Plugge
 
 This library is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself, either Perl version 5.8.8 or, at your option,
